/**********************************************************************
file: xadc_arty_core.cpp - implementation of XadcArtyCore class
Copyright (C) 2017  p. chu

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
**********************************************************************/


/*****************************************************************//**
 * @file xadc_arty_core.cpp
 *
 * @brief implementation of XadcArtyCore class
 *
 * @author p chu
 * @version v1.0: initial release
 ********************************************************************/

#include "xadc_arty_core.h"

XadcArtyCore::XadcArtyCore(uint32_t core_base_addr) {
	base_addr = core_base_addr;
}

XadcArtyCore::~XadcArtyCore() {
}

uint16_t XadcArtyCore::read_channel_raw(int n) {
	uint16_t rd_data;

	rd_data = (uint16_t) io_read(base_addr, n) & 0x0000ffff;
	return (rd_data);
}

double XadcArtyCore::read_channel_voltage(int n) {
	uint16_t raw;
	double v;

	raw = read_channel_raw(n) >> 4;
	v = (double) raw / 4096.0;
	return (v);
}

double XadcArtyCore::read_adc_in(int n) {
	double v;

	v = read_channel_voltage(AUX_0_REG + CHN_MAP[n]);
	if (n < 6) {
		v = v * 3.3; // voltage between 0 - 3.3 V (due to voltage divider)
	}
	return (v);
}

double XadcArtyCore::read_fpga_vcc() {
	double v;

	v = 3.0 * read_channel_voltage(CORE_V_REG);
	return (v);
}

double XadcArtyCore::read_vp_vn() {
	return(read_channel_voltage(VP_VN_REG));
}

double XadcArtyCore::read_fpga_temp() {
	double v, t;

	v = read_channel_voltage(TMP_REG);
	t = v * 503.975 - 273.15;
	return (t);
}

double XadcArtyCore::read_fpga_icc() {
	double v, icc;

	v = read_channel_voltage(CORE_I_REG);
	icc = 2.0 * v;
	return (icc);
}

double XadcArtyCore::read_board_v() {
	double v;

	v = read_channel_voltage(RAW_V_REG);
	v = 16.0 * v;
	return (v);
}

double XadcArtyCore::read_5v_v() {
	double v;

	v = read_channel_voltage(V5_V_REG);
	v = 5.99 * v;
	return (v);
}

double XadcArtyCore::read_5v_i() {
	double v, i5;

	v = read_channel_voltage(V5_I_REG);
	i5 = 4.0 * v;
	return (i5);
}
