module mcs_top_heat_arty_a7
#(parameter BRG_BASE = 32'hc000_0000)	
(
   input  logic clk,
   input  logic reset_n,
   // switches and LEDs
   input  logic [3:0] sw,
   output logic [3:0] led,
   // uart
   input  logic rx,
   output logic tx,          
   // arty xadc analog channels 
   input logic vp_in, vn_in,
   input logic [8:0] adc_a_p, adc_a_n,
   input logic [3:0] adc_iv_p, adc_iv_n,
   // tri-color leds (pwm) 
   output logic [2:0] rgb_led0, rgb_led1, rgb_led2, rgb_led3,
   // button
   input logic [3:0] btn,
   // arduino i/o header
   inout logic [15:0] arduino_io,
   // PMOD JA (divided into top row and bottom row)
   output logic [4:1] ja_top,
   output logic [10:7] ja_btm
);

   // declaration
   logic clk_100M;
   logic reset_sys;
   // MCS IO bus
   logic io_addr_strobe;
   logic io_read_strobe;
   logic io_write_strobe;
   logic [3:0] io_byte_enable;
   logic [31:0] io_address;
   logic [31:0] io_write_data;
   logic [31:0] io_read_data;
   logic io_ready;
   // fpro bus 
   logic fp_mmio_cs; 
   logic fp_wr;      
   logic fp_rd;     
   logic [20:0] fp_addr;       
   logic [31:0] fp_wr_data;    
   logic [31:0] fp_rd_data;    
   // pwm 
   logic [15:0] pwm; 
   // ddfs/audio pdm 
   logic pdm, ddfs_sq_wave;
   // spi
   logic sclk;
   logic mosi;
   logic miso;
   logic [3:0] ss_n;

   // body
   assign clk_100M = clk;       // 100 MHz external clock
   assign reset_sys = !reset_n;
   assign reset_sys = 1'b0;
   //  rgb leds
   assign rgb_led0 = pwm[2:0];
   assign rgb_led1 = pwm[5:3];
   assign rgb_led2 = pwm[8:6];
   assign rgb_led3 = pwm[11:9];
   // arduino header
   assign arduino_io[2] = ddfs_sq_wave;
   assign arduino_io[3] = pdm;
   assign arduino_io[7:4] = pwm[15:12];
   assign arduino_io[8] = ss_n[2];
   assign arduino_io[9] = ss_n[1];
   assign arduino_io[10] = ss_n[0];
   assign arduino_io[11] = mosi;
   assign miso = arduino_io[12];
   assign arduino_io[13] = sclk;
   // PMOD JA bottom for Pmod AMP2  
   assign ja_btm[7] = pdm; // pdm audio
   assign ja_btm[8] = 1'b0; // 1/0 for 6/12db gain 
   assign ja_btm[9] = 1'b0; // not used
   assign ja_btm[10] = 1'b1; // not shut down
   assign ja_top = 4'b0000;
  
   //instantiate uBlaze MCS
   cpu cpu_unit (
    .Clk(clk_100M),                          
    .Reset(reset_sys),                  
    .IO_addr_strobe(io_addr_strobe),    
    .IO_address(io_address),            
    .IO_byte_enable(io_byte_enable),    
    .IO_read_data(io_read_data),        
    .IO_read_strobe(io_read_strobe),    
    .IO_ready(io_ready),                
    .IO_write_data(io_write_data),      
    .IO_write_strobe(io_write_strobe)   
    );
    
   // instantiate bridge
   chu_mcs_bridge #(.BRG_BASE(BRG_BASE)) b_unit (.*, .fp_video_cs());
    
   // instantiated i/o subsystem
   mmio_sys_sampler_arty_a7  mmio_unit (
    .clk(clk),
    .reset(reset_sys),
    .mmio_cs(fp_mmio_cs),
    .mmio_wr(fp_wr),
    .mmio_rd(fp_rd),
    .mmio_addr(fp_addr), 
    .mmio_wr_data(fp_wr_data),
    .mmio_rd_data(fp_rd_data),
    .i2c_scl(arduino_io[15]),
    .i2c_sda(arduino_io[14]),
    .an(),
    .sseg(),
    .ps2d(),
    .ps2c(),          
    .*  
   );   
endmodule    
   
